@@ -16,7 +16,13 @@
    You should have received a copy of the GNU Lesser General Public
    License along with the GNU C Library; if not, write to the Free
    Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307 USA.  */
+   02111-1307 USA.
+    
+   As a special exception, you may add the source code for this file, sonic.c,
+   to your project, rather than linking against a libsonic or adding Sonic.jar,
+   but any changes to these two files must be published according to the LGPL
+   terms.
+*/
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -41,8 +47,6 @@ struct sonicStreamStruct {
     float rate;
     int oldRatePosition;
     int newRatePosition;
-    int oldSampleRate;
-    int newSampleRate;
     int useChordPitch;
     int quality;
     int numChannels;
@@ -58,7 +62,6 @@ struct sonicStreamStruct {
     int remainingInputToCopy;
     int sampleRate;
     int prevPeriod;
-    int prevMaxDiff;
     int prevMinDiff;
 };
 
@@ -443,7 +446,7 @@ static int copyToOutput(
     memcpy(stream->outputBuffer + stream->numOutputSamples*stream->numChannels,
 	samples, numSamples*sizeof(short)*stream->numChannels);
     stream->numOutputSamples += numSamples;
-    return numSamples;
+    return 1;
 }
 
 /* Just copy from the input buffer to the output buffer.  Return 0 if we fail to
@@ -596,7 +599,7 @@ int sonicSamplesAvailable(
     return stream->numOutputSamples;
 }
 
-/* If skip is greater than one, average skip samples togther and write them to
+/* If skip is greater than one, average skip samples together and write them to
    the down-sample buffer.  If numChannels is greater than one, mix the channels
    together as we down sample. */
 static void downSampleInput(
@@ -621,7 +624,7 @@ static void downSampleInput(
 }
 
 /* Find the best frequency match in the range, and given a sample skip multiple.
-   For now, just find the pitch of the first channel.  */
+   For now, just find the pitch of the first channel. */
 static int findPitchPeriodInRange(
     short *samples,
     int minPeriod,
@@ -662,7 +665,7 @@ static int findPitchPeriodInRange(
 }
 
 /* At abrupt ends of voiced words, we can have pitch periods that are better
-   aproximated by the previous pitch period estimate.  Try to detect this case.  */
+   approximated by the previous pitch period estimate.  Try to detect this case. */
 static int prevPeriodBetter(
     sonicStream stream,
     int period,
@@ -741,7 +744,6 @@ static int findPitchPeriod(
 	retPeriod = period;
     }
     stream->prevMinDiff = minDiff;
-    stream->prevMaxDiff = maxDiff;
     stream->prevPeriod = period;
     return retPeriod;
 }
@@ -810,7 +812,7 @@ static void overlapAddWithSeparation(
     }
 }
 
-/* Just move the new samples in the output buffer to the pitch bufer */
+/* Just move the new samples in the output buffer to the pitch buffer */
 static int moveNewSamplesToPitchBuffer(
     sonicStream stream,
     int originalNumOutputSamples)
@@ -980,7 +982,7 @@ static int skipPitchPeriod(
 
     if(speed >= 2.0f) {
 	newSamples = period/(speed - 1.0f);
-    } else if(speed > 1.0f) {
+    } else {
 	newSamples = period;
 	stream->remainingInputToCopy = period*(2.0f - speed)/(speed - 1.0f);
     }
